@@ -18,17 +18,23 @@ class FileScan(interfaces.plugins.PluginInterface):
     @classmethod
     def get_requirements(cls):
         return [
-            requirements.ModuleRequirement(name = 'kernel', description = 'Windows kernel',
-                                                     architectures = ["Intel32", "Intel64"]),
-            requirements.PluginRequirement(name = 'poolscanner', plugin = poolscanner.PoolScanner, version = (1, 0, 0)),
+            requirements.ModuleRequirement(
+                name="kernel",
+                description="Windows kernel",
+                architectures=["Intel32", "Intel64"],
+            ),
+            requirements.PluginRequirement(
+                name="poolscanner", plugin=poolscanner.PoolScanner, version=(1, 0, 0)
+            ),
         ]
 
     @classmethod
-    def scan_files(cls,
-                   context: interfaces.context.ContextInterface,
-                   layer_name: str,
-                   symbol_table: str) -> \
-            Iterable[interfaces.objects.ObjectInterface]:
+    def scan_files(
+        cls,
+        context: interfaces.context.ContextInterface,
+        layer_name: str,
+        symbol_table: str,
+    ) -> Iterable[interfaces.objects.ObjectInterface]:
         """Scans for file objects using the poolscanner module and constraints.
 
         Args:
@@ -40,18 +46,22 @@ class FileScan(interfaces.plugins.PluginInterface):
             A list of File objects as found from the `layer_name` layer based on File pool signatures
         """
 
-        constraints = poolscanner.PoolScanner.builtin_constraints(symbol_table, [b'Fil\xe5', b'File'])
-
-        for result in poolscanner.PoolScanner.generate_pool_scan(context, layer_name, symbol_table, constraints):
+        constraints = poolscanner.PoolScanner.builtin_constraints(
+            symbol_table, [b"Fil\xe5", b"File"]
+        )
 
+        for result in poolscanner.PoolScanner.generate_pool_scan(
+            context, layer_name, symbol_table, constraints
+        ):
             _constraint, mem_object, _header = result
             yield mem_object
 
     def _generator(self):
-        kernel = self.context.modules[self.config['kernel']]
-
-        for fileobj in self.scan_files(self.context, kernel.layer_name, kernel.symbol_table_name):
+        kernel = self.context.modules[self.config["kernel"]]
 
+        for fileobj in self.scan_files(
+            self.context, kernel.layer_name, kernel.symbol_table_name
+        ):
             try:
                 file_name = fileobj.FileName.String
             except exceptions.InvalidAddressException:
@@ -60,4 +70,7 @@ class FileScan(interfaces.plugins.PluginInterface):
             yield (0, (format_hints.Hex(fileobj.vol.offset), file_name, fileobj.Size))
 
     def run(self):
-        return renderers.TreeGrid([("Offset", format_hints.Hex), ("Name", str), ("Size", int)], self._generator())
+        return renderers.TreeGrid(
+            [("Offset", format_hints.Hex), ("Name", str), ("Size", int)],
+            self._generator(),
+        )
