@@ -23,25 +23,35 @@ class ModScan(interfaces.plugins.PluginInterface):
     @classmethod
     def get_requirements(cls):
         return [
-            requirements.ModuleRequirement(name = 'kernel', description = 'Windows kernel',
-                                                     architectures = ["Intel32", "Intel64"]),
-            requirements.VersionRequirement(name = 'poolerscanner',
-                                            component = poolscanner.PoolScanner,
-                                            version = (1, 0, 0)),
-            requirements.VersionRequirement(name = 'pslist', component = pslist.PsList, version = (2, 0, 0)),
-            requirements.VersionRequirement(name = 'dlllist', component = dlllist.DllList, version = (2, 0, 0)),
-            requirements.BooleanRequirement(name = 'dump',
-                                            description = "Extract listed modules",
-                                            default = False,
-                                            optional = True)
+            requirements.ModuleRequirement(
+                name="kernel",
+                description="Windows kernel",
+                architectures=["Intel32", "Intel64"],
+            ),
+            requirements.VersionRequirement(
+                name="poolscanner", component=poolscanner.PoolScanner, version=(1, 0, 0)
+            ),
+            requirements.VersionRequirement(
+                name="pslist", component=pslist.PsList, version=(2, 0, 0)
+            ),
+            requirements.VersionRequirement(
+                name="dlllist", component=dlllist.DllList, version=(2, 0, 0)
+            ),
+            requirements.BooleanRequirement(
+                name="dump",
+                description="Extract listed modules",
+                default=False,
+                optional=True,
+            ),
         ]
 
     @classmethod
-    def scan_modules(cls,
-                     context: interfaces.context.ContextInterface,
-                     layer_name: str,
-                     symbol_table: str) -> \
-            Iterable[interfaces.objects.ObjectInterface]:
+    def scan_modules(
+        cls,
+        context: interfaces.context.ContextInterface,
+        layer_name: str,
+        symbol_table: str,
+    ) -> Iterable[interfaces.objects.ObjectInterface]:
         """Scans for modules using the poolscanner module and constraints.
 
         Args:
@@ -53,19 +63,24 @@ class ModScan(interfaces.plugins.PluginInterface):
             A list of Driver objects as found from the `layer_name` layer based on Driver pool signatures
         """
 
-        constraints = poolscanner.PoolScanner.builtin_constraints(symbol_table, [b'MmLd'])
-
-        for result in poolscanner.PoolScanner.generate_pool_scan(context, layer_name, symbol_table, constraints):
+        constraints = poolscanner.PoolScanner.builtin_constraints(
+            symbol_table, [b"MmLd"]
+        )
 
+        for result in poolscanner.PoolScanner.generate_pool_scan(
+            context, layer_name, symbol_table, constraints
+        ):
             _constraint, mem_object, _header = result
             yield mem_object
 
     @classmethod
-    def get_session_layers(cls,
-                           context: interfaces.context.ContextInterface,
-                           layer_name: str,
-                           symbol_table: str,
-                           pids: List[int] = None) -> Generator[str, None, None]:
+    def get_session_layers(
+        cls,
+        context: interfaces.context.ContextInterface,
+        layer_name: str,
+        symbol_table: str,
+        pids: List[int] = None,
+    ) -> Generator[str, None, None]:
         """Build a cache of possible virtual layers, in priority starting with
         the primary/kernel layer. Then keep one layer per session by cycling
         through the process list.
@@ -82,10 +97,12 @@ class ModScan(interfaces.plugins.PluginInterface):
         seen_ids: List[interfaces.objects.ObjectInterface] = []
         filter_func = pslist.PsList.create_pid_filter(pids or [])
 
-        for proc in pslist.PsList.list_processes(context = context,
-                                                 layer_name = layer_name,
-                                                 symbol_table = symbol_table,
-                                                 filter_func = filter_func):
+        for proc in pslist.PsList.list_processes(
+            context=context,
+            layer_name=layer_name,
+            symbol_table=symbol_table,
+            filter_func=filter_func,
+        ):
             proc_id = "Unknown"
             try:
                 proc_id = proc.UniqueProcessId
@@ -93,9 +110,11 @@ class ModScan(interfaces.plugins.PluginInterface):
 
                 # create the session space object in the process' own layer.
                 # not all processes have a valid session pointer.
-                session_space = context.object(symbol_table + constants.BANG + "_MM_SESSION_SPACE",
-                                               layer_name = layer_name,
-                                               offset = proc.Session)
+                session_space = context.object(
+                    symbol_table + constants.BANG + "_MM_SESSION_SPACE",
+                    layer_name=layer_name,
+                    offset=proc.Session,
+                )
 
                 if session_space.SessionId in seen_ids:
                     continue
@@ -104,7 +123,9 @@ class ModScan(interfaces.plugins.PluginInterface):
                 vollog.log(
                     constants.LOGLEVEL_VVV,
                     "Process {} does not have a valid Session or a layer could not be constructed for it".format(
-                        proc_id))
+                        proc_id
+                    ),
+                )
                 continue
 
             # save the layer if we haven't seen the session yet
@@ -112,8 +133,12 @@ class ModScan(interfaces.plugins.PluginInterface):
             yield proc_layer_name
 
     @classmethod
-    def find_session_layer(cls, context: interfaces.context.ContextInterface, session_layers: Iterable[str],
-                           base_address: int):
+    def find_session_layer(
+        cls,
+        context: interfaces.context.ContextInterface,
+        session_layers: Iterable[str],
+        base_address: int,
+    ):
         """Given a base address and a list of layer names, find a layer that
         can access the specified address.
 
@@ -135,17 +160,20 @@ class ModScan(interfaces.plugins.PluginInterface):
         return None
 
     def _generator(self):
-        kernel = self.context.modules[self.config['kernel']]
+        kernel = self.context.modules[self.config["kernel"]]
 
-        session_layers = list(self.get_session_layers(self.context, kernel.layer_name, kernel.symbol_table_name))
-        pe_table_name = intermed.IntermediateSymbolTable.create(self.context,
-                                                                self.config_path,
-                                                                "windows",
-                                                                "pe",
-                                                                class_types = pe.class_types)
-
-        for mod in self.scan_modules(self.context, kernel.layer_name, kernel.symbol_table_name):
+        session_layers = list(
+            self.get_session_layers(
+                self.context, kernel.layer_name, kernel.symbol_table_name
+            )
+        )
+        pe_table_name = intermed.IntermediateSymbolTable.create(
+            self.context, self.config_path, "windows", "pe", class_types=pe.class_types
+        )
 
+        for mod in self.scan_modules(
+            self.context, kernel.layer_name, kernel.symbol_table_name
+        ):
             try:
                 BaseDllName = mod.BaseDllName.get_string()
             except exceptions.InvalidAddressException:
@@ -157,23 +185,44 @@ class ModScan(interfaces.plugins.PluginInterface):
                 FullDllName = ""
 
             file_output = "Disabled"
-            if self.config['dump']:
-
-                session_layer_name = self.find_session_layer(self.context, session_layers, mod.DllBase)
+            if self.config["dump"]:
+                session_layer_name = self.find_session_layer(
+                    self.context, session_layers, mod.DllBase
+                )
                 file_output = f"Cannot find a viable session layer for {mod.DllBase:#x}"
                 if session_layer_name:
-                    file_handle = dlllist.DllList.dump_pe(self.context,
-                                                          pe_table_name,
-                                                          mod,
-                                                          self.open,
-                                                          layer_name = session_layer_name)
+                    file_handle = dlllist.DllList.dump_pe(
+                        self.context,
+                        pe_table_name,
+                        mod,
+                        self.open,
+                        layer_name=session_layer_name,
+                    )
                     file_output = "Error outputting file"
                     if file_handle:
                         file_output = file_handle.preferred_filename
 
-            yield (0, (format_hints.Hex(mod.vol.offset), format_hints.Hex(mod.DllBase),
-                       format_hints.Hex(mod.SizeOfImage), BaseDllName, FullDllName, file_output))
+            yield (
+                0,
+                (
+                    format_hints.Hex(mod.vol.offset),
+                    format_hints.Hex(mod.DllBase),
+                    format_hints.Hex(mod.SizeOfImage),
+                    BaseDllName,
+                    FullDllName,
+                    file_output,
+                ),
+            )
 
     def run(self):
-        return renderers.TreeGrid([("Offset", format_hints.Hex), ("Base", format_hints.Hex), ("Size", format_hints.Hex),
-                                   ("Name", str), ("Path", str), ("File output", str)], self._generator())
+        return renderers.TreeGrid(
+            [
+                ("Offset", format_hints.Hex),
+                ("Base", format_hints.Hex),
+                ("Size", format_hints.Hex),
+                ("Name", str),
+                ("Path", str),
+                ("File output", str),
+            ],
+            self._generator(),
+        )
