@@ -31,16 +31,18 @@ class PoolConstraint:
     """Class to maintain tag/size/index/type information about Pool header
     tags."""
 
-    def __init__(self,
-                 tag: bytes,
-                 type_name: str,
-                 object_type: Optional[str] = None,
-                 page_type: Optional[PoolType] = None,
-                 size: Optional[Tuple[Optional[int], Optional[int]]] = None,
-                 index: Optional[Tuple[Optional[int], Optional[int]]] = None,
-                 alignment: Optional[int] = 1,
-                 skip_type_test: bool = False,
-                 additional_structures: Optional[List[str]] = None) -> None:
+    def __init__(
+        self,
+        tag: bytes,
+        type_name: str,
+        object_type: Optional[str] = None,
+        page_type: Optional[PoolType] = None,
+        size: Optional[Tuple[Optional[int], Optional[int]]] = None,
+        index: Optional[Tuple[Optional[int], Optional[int]]] = None,
+        alignment: Optional[int] = 1,
+        skip_type_test: bool = False,
+        additional_structures: Optional[List[str]] = None,
+    ) -> None:
         self.tag = tag
         self.type_name = type_name
         self.object_type = object_type
@@ -53,23 +55,30 @@ class PoolConstraint:
 
 
 class PoolHeaderScanner(interfaces.layers.ScannerInterface):
-
-    def __init__(self, module: interfaces.context.ModuleInterface, constraint_lookup: Dict[bytes, PoolConstraint],
-                 alignment: int):
+    def __init__(
+        self,
+        module: interfaces.context.ModuleInterface,
+        constraint_lookup: Dict[bytes, PoolConstraint],
+        alignment: int,
+    ):
         super().__init__()
         self._module = module
         self._constraint_lookup = constraint_lookup
         self._alignment = alignment
 
-        header_type = self._module.get_type('_POOL_HEADER')
-        self._header_offset = header_type.relative_child_offset('PoolTag')
-        self._subscanner = scanners.MultiStringScanner([c for c in constraint_lookup.keys()])
+        header_type = self._module.get_type("_POOL_HEADER")
+        self._header_offset = header_type.relative_child_offset("PoolTag")
+        self._subscanner = scanners.MultiStringScanner(
+            [c for c in constraint_lookup.keys()]
+        )
 
     def __call__(self, data: bytes, data_offset: int):
         for offset, pattern in self._subscanner(data, data_offset):
-            header = self._module.object(object_type = "_POOL_HEADER",
-                                         offset = offset - self._header_offset,
-                                         absolute = True)
+            header = self._module.object(
+                object_type="_POOL_HEADER",
+                offset=offset - self._header_offset,
+                absolute=True,
+            )
             constraint = self._constraint_lookup[pattern]
             try:
                 # Size check
@@ -87,9 +96,13 @@ class PoolHeaderScanner(interfaces.layers.ScannerInterface):
 
                     if (constraint.page_type & PoolType.FREE) and header.is_free_pool():
                         checks_pass = True
-                    elif (constraint.page_type & PoolType.NONPAGED) and header.is_nonpaged_pool():
+                    elif (
+                        constraint.page_type & PoolType.NONPAGED
+                    ) and header.is_nonpaged_pool():
                         checks_pass = True
-                    elif (constraint.page_type & PoolType.PAGED) and header.is_paged_pool():
+                    elif (
+                        constraint.page_type & PoolType.PAGED
+                    ) and header.is_paged_pool():
                         checks_pass = True
 
                     if not checks_pass:
@@ -120,38 +133,58 @@ class PoolScanner(plugins.PluginInterface):
     @classmethod
     def get_requirements(cls) -> List[interfaces.configuration.RequirementInterface]:
         return [
-            requirements.ModuleRequirement(name = 'kernel', description = 'Windows kernel',
-                                                     architectures = ["Intel32", "Intel64"]),
-            requirements.PluginRequirement(name = 'handles', plugin = handles.Handles, version = (1, 0, 0)),
+            requirements.ModuleRequirement(
+                name="kernel",
+                description="Windows kernel",
+                architectures=["Intel32", "Intel64"],
+            ),
+            requirements.PluginRequirement(
+                name="handles", plugin=handles.Handles, version=(1, 0, 0)
+            ),
         ]
 
     def _generator(self):
-
-        kernel = self.context.modules[self.config['kernel']]
+        kernel = self.context.modules[self.config["kernel"]]
 
         symbol_table = kernel.symbol_table_name
         constraints = self.builtin_constraints(symbol_table)
 
-        for constraint, mem_object, header in self.generate_pool_scan(self.context, kernel.layer_name,
-                                                                      symbol_table, constraints):
+        for constraint, mem_object, header in self.generate_pool_scan(
+            self.context, kernel.layer_name, symbol_table, constraints
+        ):
             # generate some type-specific info for sanity checking
             if constraint.object_type == "Process":
-                name = mem_object.ImageFileName.cast("string",
-                                                     max_length = mem_object.ImageFileName.vol.count,
-                                                     errors = "replace")
+                name = mem_object.ImageFileName.cast(
+                    "string",
+                    max_length=mem_object.ImageFileName.vol.count,
+                    errors="replace",
+                )
             elif constraint.object_type == "File":
                 try:
                     name = mem_object.FileName.String
                 except exceptions.InvalidAddressException:
-                    vollog.log(constants.LOGLEVEL_VVV, f"Skipping file at {mem_object.vol.offset:#x}")
+                    vollog.log(
+                        constants.LOGLEVEL_VVV,
+                        f"Skipping file at {mem_object.vol.offset:#x}",
+                    )
                     continue
             else:
                 name = renderers.NotApplicableValue()
 
-            yield (0, (constraint.type_name, format_hints.Hex(header.vol.offset), header.vol.layer_name, name))
+            yield (
+                0,
+                (
+                    constraint.type_name,
+                    format_hints.Hex(header.vol.offset),
+                    header.vol.layer_name,
+                    name,
+                ),
+            )
 
     @staticmethod
-    def builtin_constraints(symbol_table: str, tags_filter: List[bytes] = None) -> List[PoolConstraint]:
+    def builtin_constraints(
+        symbol_table: str, tags_filter: List[bytes] = None
+    ) -> List[PoolConstraint]:
         """Get built-in PoolConstraints given a list of pool tags.
 
         The tags_filter is a list of pool tags, and the associated
@@ -168,83 +201,109 @@ class PoolScanner(plugins.PluginInterface):
 
         builtins = [
             # atom tables
-            PoolConstraint(b'AtmT',
-                           type_name = symbol_table + constants.BANG + "_RTL_ATOM_TABLE",
-                           size = (200, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"AtmT",
+                type_name=symbol_table + constants.BANG + "_RTL_ATOM_TABLE",
+                size=(200, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # processes on windows before windows 8
-            PoolConstraint(b'Pro\xe3',
-                           type_name = symbol_table + constants.BANG + "_EPROCESS",
-                           object_type = "Process",
-                           size = (600, None),
-                           skip_type_test = True,
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"Pro\xe3",
+                type_name=symbol_table + constants.BANG + "_EPROCESS",
+                object_type="Process",
+                size=(600, None),
+                skip_type_test=True,
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # processes on windows starting with windows 8
-            PoolConstraint(b'Proc',
-                           type_name = symbol_table + constants.BANG + "_EPROCESS",
-                           object_type = "Process",
-                           size = (600, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"Proc",
+                type_name=symbol_table + constants.BANG + "_EPROCESS",
+                object_type="Process",
+                size=(600, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # files on windows before windows 8
-            PoolConstraint(b'Fil\xe5',
-                           type_name = symbol_table + constants.BANG + "_FILE_OBJECT",
-                           object_type = "File",
-                           size = (150, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"Fil\xe5",
+                type_name=symbol_table + constants.BANG + "_FILE_OBJECT",
+                object_type="File",
+                size=(150, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # files on windows starting with windows 8
-            PoolConstraint(b'File',
-                           type_name = symbol_table + constants.BANG + "_FILE_OBJECT",
-                           object_type = "File",
-                           size = (150, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"File",
+                type_name=symbol_table + constants.BANG + "_FILE_OBJECT",
+                object_type="File",
+                size=(150, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # mutants on windows before windows 8
-            PoolConstraint(b'Mut\xe1',
-                           type_name = symbol_table + constants.BANG + "_KMUTANT",
-                           object_type = "Mutant",
-                           size = (64, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"Mut\xe1",
+                type_name=symbol_table + constants.BANG + "_KMUTANT",
+                object_type="Mutant",
+                size=(64, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # mutants on windows starting with windows 8
-            PoolConstraint(b'Muta',
-                           type_name = symbol_table + constants.BANG + "_KMUTANT",
-                           object_type = "Mutant",
-                           size = (64, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"Muta",
+                type_name=symbol_table + constants.BANG + "_KMUTANT",
+                object_type="Mutant",
+                size=(64, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # drivers on windows before windows 8
-            PoolConstraint(b'Dri\xf6',
-                           type_name = symbol_table + constants.BANG + "_DRIVER_OBJECT",
-                           object_type = "Driver",
-                           size = (248, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE, 
-                           additional_structures = ["_DRIVER_EXTENSION"]),
+            PoolConstraint(
+                b"Dri\xf6",
+                type_name=symbol_table + constants.BANG + "_DRIVER_OBJECT",
+                object_type="Driver",
+                size=(248, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+                additional_structures=["_DRIVER_EXTENSION"],
+            ),
             # drivers on windows starting with windows 8
-            PoolConstraint(b'Driv',
-                           type_name = symbol_table + constants.BANG + "_DRIVER_OBJECT",
-                           object_type = "Driver",
-                           size = (248, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"Driv",
+                type_name=symbol_table + constants.BANG + "_DRIVER_OBJECT",
+                object_type="Driver",
+                size=(248, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # kernel modules
-            PoolConstraint(b'MmLd',
-                           type_name = symbol_table + constants.BANG + "_LDR_DATA_TABLE_ENTRY",
-                           size = (76, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"MmLd",
+                type_name=symbol_table + constants.BANG + "_LDR_DATA_TABLE_ENTRY",
+                size=(76, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # symlinks on windows before windows 8
-            PoolConstraint(b'Sym\xe2',
-                           type_name = symbol_table + constants.BANG + "_OBJECT_SYMBOLIC_LINK",
-                           object_type = "SymbolicLink",
-                           size = (72, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"Sym\xe2",
+                type_name=symbol_table + constants.BANG + "_OBJECT_SYMBOLIC_LINK",
+                object_type="SymbolicLink",
+                size=(72, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # symlinks on windows starting with windows 8
-            PoolConstraint(b'Symb',
-                           type_name = symbol_table + constants.BANG + "_OBJECT_SYMBOLIC_LINK",
-                           object_type = "SymbolicLink",
-                           size = (72, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE),
+            PoolConstraint(
+                b"Symb",
+                type_name=symbol_table + constants.BANG + "_OBJECT_SYMBOLIC_LINK",
+                object_type="SymbolicLink",
+                size=(72, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+            ),
             # registry hives
-            PoolConstraint(b'CM10',
-                           type_name = symbol_table + constants.BANG + "_CMHIVE",
-                           size = (800, None),
-                           page_type = PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
-                           skip_type_test = True),
+            PoolConstraint(
+                b"CM10",
+                type_name=symbol_table + constants.BANG + "_CMHIVE",
+                size=(800, None),
+                page_type=PoolType.PAGED | PoolType.NONPAGED | PoolType.FREE,
+                skip_type_test=True,
+            ),
         ]
 
         if not tags_filter:
@@ -253,13 +312,21 @@ class PoolScanner(plugins.PluginInterface):
         return [constraint for constraint in builtins if constraint.tag in tags_filter]
 
     @classmethod
-    def generate_pool_scan(cls,
-                           context: interfaces.context.ContextInterface,
-                           layer_name: str,
-                           symbol_table: str,
-                           constraints: List[PoolConstraint]) \
-            -> Generator[Tuple[
-                             PoolConstraint, interfaces.objects.ObjectInterface, interfaces.objects.ObjectInterface], None, None]:
+    def generate_pool_scan(
+        cls,
+        context: interfaces.context.ContextInterface,
+        layer_name: str,
+        symbol_table: str,
+        constraints: List[PoolConstraint],
+    ) -> Generator[
+        Tuple[
+            PoolConstraint,
+            interfaces.objects.ObjectInterface,
+            interfaces.objects.ObjectInterface,
+        ],
+        None,
+        None,
+    ]:
         """
 
         Args:
@@ -273,9 +340,13 @@ class PoolScanner(plugins.PluginInterface):
         """
 
         # get the object type map
-        type_map = handles.Handles.get_type_map(context = context, layer_name = layer_name, symbol_table = symbol_table)
+        type_map = handles.Handles.get_type_map(
+            context=context, layer_name=layer_name, symbol_table=symbol_table
+        )
 
-        cookie = handles.Handles.find_cookie(context = context, layer_name = layer_name, symbol_table = symbol_table)
+        cookie = handles.Handles.find_cookie(
+            context=context, layer_name=layer_name, symbol_table=symbol_table
+        )
 
         is_windows_10 = versions.is_windows_10(context, symbol_table)
         is_windows_8_or_later = versions.is_windows_8_or_later(context, symbol_table)
@@ -285,45 +356,61 @@ class PoolScanner(plugins.PluginInterface):
 
         # switch to a non-virtual layer if necessary
         if not is_windows_10:
-            scan_layer = context.layers[scan_layer].config['memory_layer']
+            scan_layer = context.layers[scan_layer].config["memory_layer"]
 
         if symbols.symbol_table_is_64bit(context, symbol_table):
             alignment = 0x10
         else:
             alignment = 8
 
-        for constraint, header in cls.pool_scan(context, scan_layer, symbol_table, constraints, alignment = alignment):
-
-            mem_objects = header.get_object(constraint = constraint,
-                                           use_top_down = is_windows_8_or_later,
-                                           native_layer_name = layer_name,
-                                           kernel_symbol_table = symbol_table)
+        for constraint, header in cls.pool_scan(
+            context, scan_layer, symbol_table, constraints, alignment=alignment
+        ):
+            mem_objects = header.get_object(
+                constraint=constraint,
+                use_top_down=is_windows_8_or_later,
+                native_layer_name=layer_name,
+                kernel_symbol_table=symbol_table,
+            )
 
             for mem_object in mem_objects:
                 if mem_object is None:
-                    vollog.log(constants.LOGLEVEL_VVV, f"Cannot create an instance of {constraint.type_name}")
+                    vollog.log(
+                        constants.LOGLEVEL_VVV,
+                        f"Cannot create an instance of {constraint.type_name}",
+                    )
                     continue
 
                 if constraint.object_type is not None and not constraint.skip_type_test:
                     try:
-                        if mem_object.get_object_header().get_object_type(type_map, cookie) != constraint.object_type:
+                        if (
+                            mem_object.get_object_header().get_object_type(
+                                type_map, cookie
+                            )
+                            != constraint.object_type
+                        ):
                             continue
                     except exceptions.InvalidAddressException:
-                        vollog.log(constants.LOGLEVEL_VVV,
-                                   f"Cannot test instance type check for {constraint.type_name}")
+                        vollog.log(
+                            constants.LOGLEVEL_VVV,
+                            f"Cannot test instance type check for {constraint.type_name}",
+                        )
                         continue
 
                 yield constraint, mem_object, header
 
     @classmethod
-    def pool_scan(cls,
-                  context: interfaces.context.ContextInterface,
-                  layer_name: str,
-                  symbol_table: str,
-                  pool_constraints: List[PoolConstraint],
-                  alignment: int = 8,
-                  progress_callback: Optional[constants.ProgressCallback] = None) \
-            -> Generator[Tuple[PoolConstraint, interfaces.objects.ObjectInterface], None, None]:
+    def pool_scan(
+        cls,
+        context: interfaces.context.ContextInterface,
+        layer_name: str,
+        symbol_table: str,
+        pool_constraints: List[PoolConstraint],
+        alignment: int = 8,
+        progress_callback: Optional[constants.ProgressCallback] = None,
+    ) -> Generator[
+        Tuple[PoolConstraint, interfaces.objects.ObjectInterface], None, None
+    ]:
         """Returns the _POOL_HEADER object (based on the symbol_table template)
         after scanning through layer_name returning all headers that match any
         of the constraints provided.  Only one constraint can be provided per
@@ -344,11 +431,13 @@ class PoolScanner(plugins.PluginInterface):
         constraint_lookup: Dict[bytes, PoolConstraint] = {}
         for constraint in pool_constraints:
             if constraint.tag in constraint_lookup:
-                raise ValueError(f"Constraint tag is used for more than one constraint: {repr(constraint.tag)}")
+                raise ValueError(
+                    f"Constraint tag is used for more than one constraint: {repr(constraint.tag)}"
+                )
             constraint_lookup[constraint.tag] = constraint
 
         pool_header_table_name = cls.get_pool_header_table(context, symbol_table)
-        module = context.module(pool_header_table_name, layer_name, offset = 0)
+        module = context.module(pool_header_table_name, layer_name, offset=0)
 
         # Run the scan locating the offsets of a particular tag
         layer = context.layers[layer_name]
@@ -356,7 +445,9 @@ class PoolScanner(plugins.PluginInterface):
         yield from layer.scan(context, scanner, progress_callback)
 
     @classmethod
-    def get_pool_header_table(cls, context: interfaces.context.ContextInterface, symbol_table: str) -> str:
+    def get_pool_header_table(
+        cls, context: interfaces.context.ContextInterface, symbol_table: str
+    ) -> str:
         """Returns the appropriate symbol_table containing a _POOL_HEADER type, even if the original symbol table
         doesn't contain one.
 
@@ -366,7 +457,9 @@ class PoolScanner(plugins.PluginInterface):
         """
         # Setup the pool header and offset differential
         try:
-            context.symbol_space.get_type(symbol_table + constants.BANG + "_POOL_HEADER")
+            context.symbol_space.get_type(
+                symbol_table + constants.BANG + "_POOL_HEADER"
+            )
             table_name = symbol_table
         except exceptions.SymbolError:
             # We have to manually load a symbol table
@@ -387,16 +480,20 @@ class PoolScanner(plugins.PluginInterface):
             else:
                 class_type = extensions.pool.POOL_HEADER
 
-            table_name = intermed.IntermediateSymbolTable.create(context = context,
-                                                                 config_path = configuration.path_join(
-                                                                     context.symbol_space[symbol_table].config_path,
-                                                                     "poolheader"),
-                                                                 sub_path = "windows",
-                                                                 filename = pool_header_json_filename,
-                                                                 table_mapping = {'nt_symbols': symbol_table},
-                                                                 class_types = {'_POOL_HEADER': class_type})
+            table_name = intermed.IntermediateSymbolTable.create(
+                context=context,
+                config_path=configuration.path_join(
+                    context.symbol_space[symbol_table].config_path, "poolheader"
+                ),
+                sub_path="windows",
+                filename=pool_header_json_filename,
+                table_mapping={"nt_symbols": symbol_table},
+                class_types={"_POOL_HEADER": class_type},
+            )
         return table_name
 
     def run(self) -> renderers.TreeGrid:
-        return renderers.TreeGrid([("Tag", str), ("Offset", format_hints.Hex), ("Layer", str), ("Name", str)],
-                                  self._generator())
+        return renderers.TreeGrid(
+            [("Tag", str), ("Offset", format_hints.Hex), ("Layer", str), ("Name", str)],
+            self._generator(),
+        )
