@@ -50,7 +50,7 @@ class proc(generic.GenericIntelProcess):
             task = self.get_task()
             current_map = task.map.hdr.links.next
         except exceptions.InvalidAddressException:
-            return
+            return None
 
         seen: Set[int] = set()
 
@@ -138,13 +138,13 @@ class vm_map_object(objects.StructType):
 class vnode(objects.StructType):
     def _do_calc_path(self, ret, vnodeobj, vname):
         if vnodeobj is None:
-            return
+            return None
 
         if vname:
             try:
                 ret.append(utility.pointer_to_string(vname, 255))
             except exceptions.InvalidAddressException:
-                return
+                return None
 
         if int(vnodeobj.v_flag) & 0x000001 != 0 and int(vnodeobj.v_mount) != 0:
             if int(vnodeobj.v_mount.mnt_vnodecovered) != 0:
@@ -158,7 +158,7 @@ class vnode(objects.StructType):
                 parent = vnodeobj.v_parent
                 parent_name = parent.v_name
             except exceptions.InvalidAddressException:
-                return
+                return None
 
             self._do_calc_path(ret, parent, parent_name)
 
@@ -502,7 +502,7 @@ class queue_entry(objects.StructType):
 
                     yielded = yielded + 1
                     if yielded == max_size:
-                        return
+                        return None
 
                     n = (
                         getattr(n.member(attr=member_name), attr)
